@@ -289,6 +289,14 @@ class Package(object):
         for filename_match in filename_matches:
             if fnmatch.fnmatch(filename, filename_match):
                 return True
+
+        # perhaps 'filename' is part of a query string, so 
+        # try a regex match 
+        for filename_match in filename_matches:
+            regex = re.compile(r'\\%s\?' % filename_match)
+            if regex.search(filename):
+                return True
+        
         return False
 
     def ls(self, filename_matches=None, external_links=False, follow_external_index_pages=False):
@@ -469,6 +477,8 @@ class Mirror(object):
                     # urllib2 when the thing was downloaded, as it might
                     # follow redirects.
                     # Example: downman.py?file=configobj-4.3.0.zip
+                    if '?' in filename:
+                        filename = filename[:filename.find('?')]
                     mirror_package.write(filename, data, md5_hash)
                     stats.stored(filename)
                     full_list.append(mirror_package._html_link(base_url, filename, md5_hash))
@@ -730,3 +740,5 @@ def run(args=None):
                       follow_external_index_pages,
                       config["base_url"])
 
+if __name__ == '__main__':
+    sys.exit(run())
